@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.004';
+our $VERSION = '1.005';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -35,6 +35,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-09-10 - v1.005
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.018.
+
+=item *
+
 2012-08-27 - v1.004
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.016.
@@ -599,6 +605,7 @@ APEIRON
 APERROTT
 APERSAUD
 APH
+APHILIPP
 APILOS
 APKELLY
 APLA
@@ -662,6 +669,7 @@ ARNHEMCR
 ARNIE
 ARNSHOLT
 ARODLAND
+ARODRIGZ
 AROTH
 ARPADF
 ARPI
@@ -720,6 +728,7 @@ ASK
 ASKADNA
 ASKSH
 ASLETT
+ASMOLECK
 ASNMTAP
 ASOKO
 ASOKOLOV
@@ -912,6 +921,7 @@ BBCPKENT
 BBCSIMONF
 BBEAUSEJ
 BBEELEY
+BBELDERB
 BBENNETT
 BBIKER
 BBIMBER
@@ -1476,6 +1486,7 @@ CARSON
 CARSWELL
 CARTER
 CARWASH
+CASAO
 CASEY
 CASIANO
 CASSJ
@@ -1701,6 +1712,7 @@ CKJ
 CKONG
 CKRAS
 CKRUSE
+CKUELKER
 CLACO
 CLADI
 CLAESJAC
@@ -1790,6 +1802,7 @@ COKE
 COLEMAN
 COLEMINOR
 COLINCCI
+COLINCYR
 COLINFINE
 COLINK
 COLINM
@@ -2206,6 +2219,7 @@ DELAREY
 DELBOY
 DELDUCRA
 DELON
+DELPHINUS
 DELTA
 DEMERY
 DEMIAN
@@ -2394,6 +2408,7 @@ DLAMBLEY
 DLAND
 DLANE
 DLECONTE
+DLEE
 DLEIGH
 DLIM
 DLINCOLN
@@ -2473,6 +2488,7 @@ DONDRAKE
 DONEILL
 DONGXU
 DONGYI
+DONKS
 DONM
 DONOR
 DONS
@@ -2518,6 +2534,7 @@ DPOKORNY
 DPR
 DPRANTL
 DPRICE
+DQNEO
 DRAEGTUN
 DRAGMZ
 DRAGONFLY
@@ -2546,6 +2563,7 @@ DRLARO
 DROBERTS
 DROLSKY
 DROOGIE
+DRORR
 DRPROLIX
 DRRHO
 DRSAARON
@@ -2608,6 +2626,7 @@ DTHOMAS
 DTHOREAU
 DTIBERIO
 DTJANEZIC
+DTORRES
 DTOWN
 DTREDER
 DTRISCHUK
@@ -3075,6 +3094,7 @@ FOOF
 FOOLFISH
 FOOLISH
 FOOP
+FORCERY
 FORMAN
 FORMORER
 FORREST
@@ -3152,6 +3172,7 @@ FUJIMURA
 FUJISAWA
 FUJIWARA
 FUKAI
+FUKATA
 FUKUDA
 FUKUMURA
 FULLERMD
@@ -3482,6 +3503,7 @@ GTERMARS
 GTHEALL
 GTHYNI
 GUELICH
+GUEUX
 GUGOD
 GUGU
 GUIDO
@@ -3548,6 +3570,7 @@ HAMANO
 HAMBSTER
 HAMEZ
 HAMID
+HAMLETT
 HAMMOND
 HAMPTON
 HANAXIS
@@ -3577,6 +3600,7 @@ HARLINH
 HARMONIE
 HARPREET
 HARRY
+HARRYPAN
 HARSHAG
 HARTMAN
 HARTZELL
@@ -3656,6 +3680,7 @@ HFAHE
 HFB
 HFINKEL
 HFOLLMANN
+HGDEV
 HGNENG
 HGOTTFR
 HHOLZ
@@ -3879,6 +3904,7 @@ IKANUSIM
 IKEBE
 IKEGAMI
 IKETRIS
+IKHRNET
 IKLUFT
 IKUTA
 ILER
@@ -4008,6 +4034,7 @@ JABBAS
 JABLKO
 JABRA
 JABURO
+JAC
 JACEK
 JACKAL
 JACKB
@@ -4083,6 +4110,7 @@ JANU
 JANUS
 JANW
 JAOS
+JAPA
 JAR
 JARED
 JARIAALTO
@@ -4299,6 +4327,7 @@ JFENAL
 JFF
 JFINGER
 JFITZ
+JFLAHERTY
 JFLOURNOY
 JFLOWERS
 JFLUHMANN
@@ -4421,6 +4450,7 @@ JKISER
 JKISTER
 JKLEPEK
 JKNEPLEY
+JKNOTT
 JKOBIE
 JKODIS
 JKONDO
@@ -4482,6 +4512,7 @@ JMBO
 JMCADA
 JMCGUIRE
 JMCNAMARA
+JMEGERMAN
 JMEHNLE
 JMELANSON
 JMELTZER
@@ -4579,6 +4610,7 @@ JOHNYJH
 JOKERGOO
 JOKKE
 JOLANDE
+JOMON
 JON
 JONADAB
 JONALLEN
@@ -4601,6 +4633,7 @@ JONJAY
 JONMORGAN
 JONO
 JONOZZZ
+JONTAYLOR
 JONTY
 JOOON
 JORDAN
@@ -4612,6 +4645,7 @@ JOSEBA
 JOSEF
 JOSEIBERT
 JOSEPHW
+JOSERIJO
 JOSERODR
 JOSEVNZ
 JOSEWEEKS
@@ -4867,6 +4901,7 @@ KARASIK
 KARAVELOV
 KARDEL
 KARHU
+KARINILS
 KARIR
 KARJALA
 KARLON
@@ -4888,6 +4923,7 @@ KAUFMANN
 KAVEHMZ
 KAVITHA
 KAWABATA
+KAWAMURAY
 KAWASAKI
 KAYSB
 KAZEBURO
@@ -5440,8 +5476,10 @@ LINKDD
 LINKE
 LINMAR
 LINNIN
+LINPC
 LINSALROB
 LINTDOG
+LINUS
 LIOL
 LION
 LIOSHA
@@ -5613,6 +5651,7 @@ MAG
 MAGGIEXYZ
 MAGH
 MAGICIAN
+MAGIKMAN
 MAGNACHEF
 MAGNEW
 MAGNUS
@@ -6396,6 +6435,7 @@ MRPALMER
 MRPERSON
 MRSAM
 MRSCOTTY
+MRSLX
 MRTS
 MRUIZ
 MRWHIPPLE
@@ -6595,6 +6635,7 @@ NAUGHTON
 NAUNIDH
 NAVIN
 NAVNEET
+NAZAROV
 NAZGUL
 NAZRI
 NBAREIL
@@ -6624,6 +6665,7 @@ NEGR
 NEIKON
 NEIL
 NEILB
+NEILBAWD
 NEILW
 NEJIGANE
 NEKOKAK
@@ -6980,6 +7022,7 @@ PALVARO
 PAMAG
 PANDICH
 PANGJ
+PANIKAL
 PANKY
 PANOLEX
 PANYU
@@ -7440,6 +7483,7 @@ PURDY
 PURL
 PURP
 PUSHPARAJ
+PUSHTAEV
 PVANDE
 PVANDRY
 PVERD
@@ -7502,6 +7546,7 @@ RAF
 RAFAEL
 RAFALUCAS
 RAGA
+RAGEFOUR
 RAGHURAM
 RAGOFF
 RAGRO
@@ -7965,6 +8010,7 @@ RSZENO
 RTFIREFLY
 RTHANGAM
 RTHOMPSON
+RTWARD
 RUBINJ
 RUBLIND
 RUBYKAT
@@ -8199,6 +8245,7 @@ SCRUBB
 SCW
 SCYLDINGA
 SDAGUE
+SDAODEN
 SDAVE
 SDD
 SDECASTE
@@ -9256,6 +9303,7 @@ TONODERA
 TONVOON
 TONYAVRIL
 TONYC
+TONYO
 TOONA
 TOPHER
 TOPIA
@@ -9395,6 +9443,7 @@ TYRU
 TZADIKV
 UARUN
 UASI
+UCHIKO
 UDASSIN
 UDHAY
 UEW
@@ -9492,6 +9541,7 @@ VEDGE
 VEEP
 VELJKO
 VELTZER
+VEN
 VENKAACT
 VENOMOUS
 VENTRAIP
@@ -9581,6 +9631,7 @@ VRUOTTI
 VSANCHEZ
 VSARKISS
 VSEGO
+VSESPB
 VSPADER
 VSSANOJ
 VTI
@@ -9949,6 +10000,7 @@ YOUD
 YOUNG
 YOURABI
 YOWCOW
+YPANDIT
 YPERL
 YRCHEN
 YRESNOB
@@ -10023,6 +10075,7 @@ ZEMAN
 ZENIN
 ZENOG
 ZENSPIDER
+ZENTLIM
 ZENTOOO
 ZEPHG
 ZERHASH
